@@ -29,7 +29,7 @@ from pythonbuilder.utils import as_list
 
 use_plugin("python.core")
 
-DATA_FILES_PROPERTY = 'distutils_data_files'
+DATA_FILES_PROPERTY = "distutils_data_files"
 SETUP_TEMPLATE = string.Template(
 """#!/usr/bin/env python
 
@@ -51,7 +51,7 @@ if __name__ == '__main__':
           $data_files
           $package_data
           $dependencies
-          $build_dependencies
+          $dependency_links
           zip_safe=True
     )
 """)
@@ -65,8 +65,8 @@ def default (value, default=""):
 def initialize_distutils_plugin (project):
     project.set_property_if_unset("distutils_commands", ["sdist", "bdist_dumb"])
     project.set_property_if_unset("distutils_classifiers", [
-      'Development Status :: 3 - Alpha',
-      'Programming Language :: Python'
+      "Development Status :: 3 - Alpha",
+      "Programming Language :: Python"
       ])
     project.set_property_if_unset("distutils_use_setuptools", True)
 
@@ -75,7 +75,6 @@ def initialize_distutils_plugin (project):
 def write_setup_script (project, logger):
     setup_script = project.expand_path("$dir_dist/setup.py")
     logger.info("Writing setup.py as %s", setup_script)
-
    
     with open(setup_script, "w") as setup_file:    
         setup_file.write(render_setup_script(project))
@@ -104,7 +103,7 @@ def render_setup_script (project):
         "data_files": build_data_files_string(project),
         "package_data": build_package_data_string(project),
         "dependencies": build_install_dependencies_string(project),
-        "build_dependencies": build_build_dependencies_string(project)
+        "dependency_links": build_dependency_links_string(project),
     }
     
     return SETUP_TEMPLATE.substitute(template_values)
@@ -112,10 +111,11 @@ def render_setup_script (project):
 
 @after("package")
 def write_manifest_file (project, logger):
-    logger.debug("MANIFEST.in: %s " % project.manifest_included_files)
     if len(project.manifest_included_files) == 0:
-        logger.debug("no data to write into MANIFEST.in")
+        logger.debug("No data to write into MANIFEST.in")
         return
+    
+    logger.debug("Files included in MANIFEST.in: %s" % project.manifest_included_files)
      
     manifest_filename = project.expand_path("$dir_dist/MANIFEST.in")
     logger.info("Writing MANIFEST.in as %s", manifest_filename)
@@ -154,32 +154,31 @@ def build_binary_distribution (project, logger):
                                         shell=False)
             return_code = process.wait()
             if return_code != 0:
-                raise BuildFailedException("Error while executing setup command %s",
-                                           command)
+                raise BuildFailedException("Error while executing setup command %s", command)
                 
 def build_install_dependencies_string (project):
-    if not project.dependencies:
+    dependencies = [dependency for dependency in project.dependencies if not dependency.url]
+    if not dependencies:
         return ""
-    result = "install_requires = [ "
     
     def format_single_dependency (dependency):
-        return '"%s%s"' % (dependency.name, 
-                           build_dependency_version_string(dependency))
+        return '"%s%s"' % (dependency.name, build_dependency_version_string(dependency))
     
-    result += ", ".join(map(format_single_dependency, project.dependencies))
+    result = "install_requires = [ "
+    result += ", ".join(map(format_single_dependency, dependencies))
     result += " ],"
     return result
 
-def build_build_dependencies_string (project):
-    if not project.build_dependencies:
+def build_dependency_links_string (project):
+    dependency_links = [dependency for dependency in project.dependencies if dependency.url]
+    if not dependency_links:
         return ""
-    result = "tests_requires = [ "
     
     def format_single_dependency (dependency):
-        return '"%s%s"' % (dependency.name, 
-                           build_dependency_version_string(dependency))
+        return '"%s"' % (dependency.url)
     
-    result += ", ".join(map(format_single_dependency, project.build_dependencies))
+    result = "dependency_links = [ "
+    result += ", ".join(map(format_single_dependency, dependency_links))
     result += " ],"
     return result
 
@@ -197,19 +196,18 @@ def build_scripts_string (project):
         
     return str(scripts)
 
-
 def build_data_files_string (project):
     data_files = project.files_to_install
     
     if data_files == []:
-        return ''
+        return ""
 
-    return 'data_files = %s,' % str(data_files)
+    return "data_files = %s," % str(data_files)
 
 def build_package_data_string (project):
     package_data = project.package_data
     if package_data == {}:
-        return ''
+        return ""
     package_data_string = "package_data = {"
     
     sorted_keys = sorted(package_data.keys())
@@ -219,8 +217,7 @@ def build_package_data_string (project):
         package_data_string += "'%s': %s" % (key, str(package_data[key]))
         
         if key is not last_element:
-            package_data_string += ', '
+            package_data_string += ", "
     
     package_data_string += "},"
     return package_data_string
-
